@@ -11,6 +11,8 @@ from .view import View
 from .view import ViewManager
 from .trigger import Trigger
 from .trigger import TriggerManager
+from .procedure import Procedure
+from .procedure import ProcedureManager
 from .notes import Note
 from .notes import NoteManager
 from ..utils.populate import auto_populate_from_keys
@@ -21,6 +23,7 @@ class Schema(BaseSchema):
     tables_: dict[str, Table] = pydantic.Field(default_factory=dict, alias='tables')
     views_: dict[str, View] = pydantic.Field(default_factory=dict, alias='views')
     triggers_: dict[str, Trigger] = pydantic.Field(default_factory=dict, alias='triggers')
+    procedures_: dict[str, Procedure] = pydantic.Field(default_factory=dict, alias='procedures')
     notes_: list[Note] = pydantic.Field(default_factory=list, alias='notes')
 
     @property
@@ -35,6 +38,10 @@ class Schema(BaseSchema):
     def triggers(self) -> TriggerManager:
         return TriggerManager(self.triggers_)
 
+    @property
+    def procedures(self) -> ProcedureManager:
+        return ProcedureManager(self.procedures_)
+
     @property
     def notes(self) -> NoteManager:
         return NoteManager(self.notes_)
@@ -43,6 +50,7 @@ class Schema(BaseSchema):
         self.tables_.update(other.tables_)
         self.views_.update(other.views_)
         self.triggers_.update(other.triggers_)
+        self.procedures_.update(other.procedures_)
         self.notes_.extend(other.notes_)
 
 
@@ -65,6 +73,8 @@ class SchemaManager(BaseSchema):
             'schemas.$1.views.$2.view_name': '$2',
             'schemas.$1.triggers.$2.instance': '$1',
             'schemas.$1.triggers.$2.trigger_name': '$2',
+            'schemas.$1.procedures.$2.instance': '$1',
+            'schemas.$1.procedures.$2.procedure_name': '$2',
         })
         return cls(**populated_data)
 
